@@ -56,9 +56,15 @@ $  usage of the function and type of the parameters
 
 
 /*
- * $Id: matc.c,v 1.3 2005/08/25 13:44:22 vierinen Exp $ 
+ * $Id: matc.c,v 1.6 2006/02/07 10:21:42 jpr Exp $ 
  *
  * $Log: matc.c,v $
+ * Revision 1.6  2006/02/07 10:21:42  jpr
+ * Changed visibility of some variables to local scope.
+ *
+ * Revision 1.5  2006/02/02 06:54:44  jpr
+ * small formatting changes.
+ *
  * Revision 1.3  2005/08/25 13:44:22  vierinen
  * windoze stuff
  *
@@ -68,9 +74,6 @@ $  usage of the function and type of the parameters
  * Revision 1.1.1.1  2005/04/14 13:29:14  vierinen
  * initial matc automake package
  *
- * Revision 1.3  2002/10/09 10:28:04  jpr
- * *** empty log message ***
- *
  * Revision 1.2  1998/08/01 12:34:48  jpr
  *
  * Added Id, started Log.
@@ -84,8 +87,8 @@ $  usage of the function and type of the parameters
 #include "../config.h"
 
 #ifdef DEBUG
-      FILE *fplog;
-      int tot;
+      static FILE *fplog;
+      static int tot;
 #endif
 /*======================================================================
 ? main program, initialize few constants and go for it.
