@@ -56,9 +56,12 @@ $  usage of the function and type of the parameters
 
 
 /*
- * $Id: parser.c,v 1.4 2006/02/02 06:54:44 jpr Exp $ 
+ * $Id: parser.c,v 1.5 2006/11/22 10:57:14 jpr Exp $ 
  *
  * $Log: parser.c,v $
+ * Revision 1.5  2006/11/22 10:57:14  jpr
+ * *** empty log message ***
+ *
  * Revision 1.4  2006/02/02 06:54:44  jpr
  * small formatting changes.
  *
@@ -269,7 +272,7 @@ TREE *nameorvar()
   root = treeptr = prevtree = newtree();
 
   if (symbol == minus && !isspace(*str) &&
-     (isspace(*(str-2)) || char_in_list(*(str-2),"{};=[(\\<>&|+-*/^,")))
+     (str-2<buf || isspace(*(str-2)) || char_in_list(*(str-2),"{};=[(\\<>&|+-*/^,")))
   {
     sym = minus; scan();
   }
@@ -394,7 +397,7 @@ TREE *nameorvar()
     scan();
 
     if (symbol == minus && !isspace(*str) &&
-         (isspace(*(str-2)) || char_in_list(*(str-2),"{};=([\\<>&|+-*/^,")))
+         (str-2<buf || isspace(*(str-2)) || char_in_list(*(str-2),"{};=([\\<>&|+-*/^,")))
     {
       sym = minus;
 
@@ -919,7 +922,7 @@ TREE *equation()
         treeptr = par_compare(treeptr); 
       break;
 
-      case plus: case minus: 
+      case plus: case minus:
         treeptr = par_plusminus(treeptr);
       break;
 
